==> jc-1.4.0.tar.gz: javax/naming/directory/BasicAttributes__24BasicAttributesEnumeration.h <==
// class javax.naming.directory.BasicAttributes$BasicAttributesEnumeration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 92a24d09edde03e6 javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration_H_
#define _JC_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_directory_BasicAttributes$object;

// Typedefs
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_refs	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_refs;
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_nonrefs	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_nonrefs;
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$refs	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$refs;
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$nonrefs	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$nonrefs;
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object;

typedef const struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vmethods	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vmethods;
typedef const struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtable	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtable;
typedef const struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype;

// Constructors
extern void _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$_init$54f97d03224bceef(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *, struct _jc_javax_naming_directory_BasicAttributes$object *, jboolean);

// Virtual methods
extern void _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
extern jboolean _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$hasMore$1fc147586a714e39(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
extern jboolean _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
extern void _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$hasMore$1fc147586a714e39;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
	jboolean	(*hasMore$1fc147586a714e39)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *);
};

// Vtable
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vmethods	javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration;
};

// Vtype
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_refs {
	struct _jc_javax_naming_directory_BasicAttributes$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$refs {
    _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_refs	javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_nonrefs {
	jint	where;
	jboolean	id;
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_nonrefs	javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration;
};

// Object instance structure
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object {
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype	*vtype;
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$class_object;

#endif	/* _JC_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration_H_ */

==> jc-1.4.6.tar.gz: javax/naming/directory/BasicAttributes__24BasicAttributesEnumeration.h <==
// class javax.naming.directory.BasicAttributes$BasicAttributesEnumeration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 92a24d09edde03e6 javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration_H_
#define _JC_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_naming_directory_BasicAttributes$object;

// Typedefs
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_refs	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_refs;
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_nonrefs	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_nonrefs;
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$refs	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$refs;
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$nonrefs	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$nonrefs;
typedef struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object;

typedef const struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vmethods	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vmethods;
typedef const struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtable	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtable;
typedef const struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype;

// Constructors
extern void _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$_init$54f97d03224bceef(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *, struct _jc_javax_naming_directory_BasicAttributes$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$hasMore$1fc147586a714e39(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$hasMore$1fc147586a714e39;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
	jboolean	(*hasMore$1fc147586a714e39)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vmethods	javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration;
};

// Vtype
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_refs {
	struct _jc_javax_naming_directory_BasicAttributes$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$refs {
    _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_refs	javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_nonrefs {
	jint	where;
	jboolean	id;
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$sub_nonrefs	javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration;
};

// Object instance structure
struct _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$object {
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype	*vtype;
	_jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$vtype _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration$class_object;

#endif	/* _JC_javax_naming_directory_BasicAttributes__24BasicAttributesEnumeration_H_ */
